"""
Este é um método para listas aninhadas!
"""
def print_lol(alista):
    """
    Este método recebe uma lista como parametro e faz todo o 
    processamento
    """
    for each in alista:
        if isinstance (each, list):
            print_lol(each)
        else:
            print (each)



from distutils.core import setup

setup(
    name            = 'pg_37',
    version         = '1.0.0',
    py_modules      = ['pg_37'],
    author          = 'rafaelmcouto',
    author_mail     = 'rafaelmcouto@gmail.com',
    url             = '',
    description     = 'A simple printer of nester lists'
)
